@@ -19,8 +19,11 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 #include "trackermodel.h"
+
 #include <QList>
-#include <klocale.h>
+
+#include <KLocalizedString>
+
 #include <interfaces/torrentinterface.h>
 #include <interfaces/trackerinterface.h>
 
@@ -28,7 +31,7 @@ namespace kt
 {
 
 	TrackerModel::TrackerModel(QObject* parent)
-			: QAbstractTableModel(parent),tc(0)
+			: QAbstractTableModel(parent),tc(nullptr)
 	{
 		running = false;
 	}
@@ -115,7 +118,7 @@ namespace kt
 		}
 		else if (role == Qt::ForegroundRole && index.column() == 1 && trk->trackerStatus() == bt::TRACKER_ERROR)
 		{
-			return Qt::red;
+			return QVariant::fromValue(Qt::red);
 		}
 		
 		return QVariant();
@@ -128,7 +131,7 @@ namespace kt
 		
 		if (role == Qt::CheckStateRole)
 		{
-			KUrl url = trackers.at(index.row())->trk->trackerURL();
+			QUrl url = trackers.at(index.row())->trk->trackerURL();
 			tc->getTrackersList()->setTrackerEnabled(url,(Qt::CheckState)value.toUInt() == Qt::Checked);
 			return true;
 		}
@@ -188,7 +191,7 @@ namespace kt
 			for (int i = 0;i < count;i++)
 			{
 				Item* item = trackers.takeAt(row);
-				KUrl url = item->trk->trackerURL();
+				QUrl url = item->trk->trackerURL();
 				tc->getTrackersList()->removeTracker(url);
 				delete item;
 			}
@@ -214,10 +217,10 @@ namespace kt
 	}
 
 	
-	KUrl TrackerModel::trackerUrl(const QModelIndex & index)
+	QUrl TrackerModel::trackerUrl(const QModelIndex & index)
 	{
 		if (!tc || !index.isValid() ||  index.row() < 0 || index.row() >= trackers.count())
-			return KUrl();
+			return QUrl();
 		
 		return ((Item*)index.internalPointer())->trk->trackerURL();
 	}
@@ -280,7 +283,7 @@ namespace kt
 	{
 		switch (column)
 		{
-			case 0: return trk->trackerURL().prettyUrl();
+			case 0: return trk->trackerURL().toDisplayString();
 			case 1: return trk->trackerStatusString();
 			case 2: return seeders >= 0 ? seeders : QVariant();
 			case 3: return leechers >= 0 ? leechers : QVariant();
@@ -301,7 +304,7 @@ namespace kt
 	{
 		switch (column)
 		{
-			case 0: return trk->trackerURL().prettyUrl();
+			case 0: return trk->trackerURL().toDisplayString();
 			case 1: return status;
 			case 2: return seeders;
 			case 3: return leechers;
