@@ -17,6 +17,7 @@
 #include "core/kget.h"
 #include "core/filemodel.h"
 #include "core/download.h"
+#include "kget_version.h"
 
 #include <torrent/torrent.h>
 #include <peer/peermanager.h>
@@ -32,18 +33,18 @@
 #include <version.h>
 
 #include "kget_debug.h"
-#include <QDebug>
 #include <KLocalizedString>
 #include <KIconLoader>
 #include <KIO/CopyJob>
 #include <KStandardDirs>
-#include <QUrl>
 #include <KMessageBox>
 
-#include <QFile>
-#include <QDomElement>
-#include <QFileInfo>
+#include <QDebug>
 #include <QDir>
+#include <QDomElement>
+#include <QFile>
+#include <QFileInfo>
+#include <QUrl>
 
 #ifdef ERROR
 #undef ERROR
@@ -128,7 +129,7 @@ void BTTransfer::start()
         {
             qCDebug(KGET_DEBUG) << m_dest.path();
             m_tmpTorrentFile = QString(KStandardDirs::locateLocal("appdata", "tmp/") + m_dest.fileName());
-            Download *download = new Download(m_source, m_tmpTorrentFile);
+            Download *download = new Download(m_source, QUrl::fromLocalFile(m_tmpTorrentFile));
 
             setStatus(Job::Stopped, i18n("Downloading Torrent File...."), SmallIcon("document-save"));
             setTransferChange(Tc_Status, true);
@@ -422,7 +423,7 @@ void BTTransfer::btTransferInit(const QUrl &src, const QByteArray &data)
 
     bt::InitLog(KStandardDirs::locateLocal("appdata", "torrentlog.log"), false, false);//initialize the torrent-log
 
-    bt::SetClientInfo("KGet", 2, 95, 0, bt::NORMAL, "KG");//Set client info to KGet TODO: don't hardcode version number
+    bt::SetClientInfo("KGet", KGET_VERSION_MAJOR, KGET_VERSION_MINOR, KGET_VERSION_PATCH, bt::NORMAL, "KG");//Set client info to KGet
 
     bt::Uint16 i = 0;
     while (!bt::Globals::instance().initTCPServer(BittorrentSettings::port() + i) && i < 10)
@@ -458,7 +459,7 @@ void BTTransfer::btTransferInit(const QUrl &src, const QByteArray &data)
         m_dest = m_dest.adjusted(QUrl::StripTrailingSlash);
         torrent->init(nullptr, file.readAll(), m_tmp + m_source.fileName().remove(".torrent"), QUrl::fromLocalFile(m_dest.adjusted(QUrl::RemoveFilename).path()).toLocalFile());
 
-        m_dest = torrent->getStats().output_path;
+        m_dest = QUrl::fromLocalFile(torrent->getStats().output_path);
         if (!torrent->getStats().multi_file_torrent && (m_dest.fileName() != torrent->getStats().torrent_name))//TODO check if this is needed, so if that case is true at some point
         {
             m_dest = m_dest.adjusted(QUrl::StripTrailingSlash);
